@@ -12,3 +12,9 @@ echo ""
 echo "Files installed as follows: "
 echo "Configuration ----->      /etc/gShield.conf"
 echo "Main script, etc -->	/etc/firewall/"
+
+echo "adjusting permissions"
+
+chmod 750 /etc/firewall
+chmod 640 /etc/firewall/*
+chmod 700 /etc/firewall/gShield.rc
